@@ -3,7 +3,7 @@ package Dist::Zilla::PluginBundle::Author::SKIRMESS;
 use strict;
 use warnings;
 
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 
 use Moose 0.99;
 use namespace::autoclean 0.09;
@@ -19,19 +19,19 @@ sub configure {
     $self->add_plugins(
 
         # Add contributor names from git to your distribution
-        ['Git::Contributors'],
+        'Git::Contributors',
 
         # Gather all tracked files in a Git working directory
         [
             'Git::GatherDir',
             {
                 ':version'       => '2.016',
-                exclude_filename => [qw( cpanfile dist.ini LICENSE Makefile.PL META.json META.yml README.md )],
+                exclude_filename => [qw( cpanfile dist.ini INSTALL LICENSE Makefile.PL META.json META.yml README.md )],
             }
         ],
 
         # Set the distribution version from your main module's $VERSION
-        ['VersionFromMainModule'],
+        'VersionFromMainModule',
 
         # Bump and reversion $VERSION on release
         [
@@ -58,8 +58,16 @@ sub configure {
             }
         ],
 
+        # Ensure no pending commits on a remote branch before release
+        [
+            'Git::Remote::Check',
+            {
+                do_update => 0,
+            }
+        ],
+
         # Decline to build files that appear in a MANIFEST.SKIP-like file
-        ['ManifestSkip'],
+        'ManifestSkip',
 
         # automatically extract prereqs from your modules
         [
@@ -122,69 +130,97 @@ sub configure {
         ],
 
         # Add Dist::Zilla authordeps to META files as develop prereqs
-        ['Prereqs::AuthorDeps'],
+        'Prereqs::AuthorDeps',
+
+        # Summarize Dist::Zilla configuration into distmeta
+        'MetaConfig',
 
         # Produce a META.yml
-        ['MetaYAML'],
+        'MetaYAML',
 
         # Produce a META.json
-        ['MetaJSON'],
+        'MetaJSON',
 
         # Produce a cpanfile prereqs file
-        ['CPANFile'],
+        'CPANFile',
 
         # Automatically convert POD to a README in any format for Dist::Zilla
         [ 'ReadmeAnyFromPod', 'ReadmeAnyFromPod/ReadmeTextInBuild' ],
 
         # Set copyright year from git
-        ['CopyrightYearFromGit'],
+        'CopyrightYearFromGit',
 
         # Output a LICENSE file
-        ['License'],
+        'License',
+
+        # Build an INSTALL file
+        [
+            'InstallGuide',
+            {
+                ':version' => '1.200007',
+            }
+        ],
 
         # Install a directory's contents as executables
-        ['ExecDir'],
+        'ExecDir',
 
         # Install a directory's contents as "ShareDir" content
-        ['ShareDir'],
+        'ShareDir',
 
         # Build a Makefile.PL that uses ExtUtils::MakeMaker
-        ['MakeMaker'],
+        'MakeMaker',
 
         # Build a MANIFEST file
-        ['Manifest'],
+        'Manifest',
 
         # Copy (or move) specific files after building (for SCM inclusion, etc.)
         [
             'CopyFilesFromBuild',
             {
-                copy => [qw( cpanfile LICENSE Makefile.PL META.json META.yml )],
+                copy => [qw( cpanfile INSTALL LICENSE Makefile.PL META.json META.yml )],
             }
         ],
 
         # Check that you're on the correct branch before release
-        ['Git::CheckFor::CorrectBranch'],
+        'Git::CheckFor::CorrectBranch',
+
+        # Check your repo for merge-conflicted files
+        'Git::CheckFor::MergeConflicts',
 
         # Ensure META includes resources
-        ['CheckMetaResources'],
+        'CheckMetaResources',
 
         # Prevent a release if you have prereqs not found on CPAN
-        ['CheckPrereqsIndexed'],
+        'CheckPrereqsIndexed',
 
         # Ensure Changes has content before releasing
-        ['CheckChangesHasContent'],
+        'CheckChangesHasContent',
+
+        # Check if your distribution declares a dependency on itself
+        'CheckSelfDependency',
+
+        # BeforeRelease plugin to check for a strict version number
+        [
+            'CheckStrictVersion',
+            {
+                decimal_only => 1,
+            }
+        ],
 
         # Support running xt tests via dzil test
-        ['RunExtraTests'],
+        'RunExtraTests',
 
         # Extract archive and run tests before releasing the dist
-        ['TestRelease'],
+        'TestRelease',
+
+        # Retrieve count of outstanding RT and github issues for your distribution
+        'CheckIssues',
 
         # Prompt for confirmation before releasing
-        ['ConfirmRelease'],
+        'ConfirmRelease',
 
         # Upload the dist to CPAN
-        [ $ENV{FAKE_RELEASE} ? 'FakeRelease' : 'UploadToCPAN' ],
+        'UploadToCPAN',
 
         # Copy files from a release (for SCM inclusion, etc.)
         [
@@ -199,7 +235,7 @@ sub configure {
             'Git::Commit',
             {
                 commit_msg        => '%v',
-                allow_dirty       => [qw(Changes cpanfile dist.ini LICENSE Makefile.PL META.json META.yml README.md)],
+                allow_dirty       => [qw(Changes cpanfile dist.ini INSTALL LICENSE Makefile.PL META.json META.yml README.md)],
                 allow_dirty_match => '\.pm$',
             }
         ],
@@ -214,8 +250,13 @@ sub configure {
         ],
 
         # Push current branch
-        ['Git::Push'],
+        'Git::Push',
 
+        # Update your github repository description from abstract on release
+        'UpdateGitHub',
+
+        # Compare data and files at different phases of the distribution build process
+        'VerifyPhases',
     );
 
     return;
@@ -229,8 +270,8 @@ __END__
 
 =head1 SYNOPSIS
 
-# in dist.ini
-[@Author::SKIRMESS]
+  # in dist.ini
+  [@Author::SKIRMESS]
 
 =head1 USAGE
 
